@@ -3,14 +3,14 @@
 use strict;
 use warnings;
 
-use Test::Shared::Fixture::Wikibase::Datatype::Value::Item::Wikidata::Douglas;
+use Test::Shared::Fixture::Wikibase::Datatype::Value::Item::Wikidata::Michal;
 use Wikibase::Datatype::Print::Value::Item;
 
 # Object.
-my $obj = Test::Shared::Fixture::Wikibase::Datatype::Value::Item::Wikidata::Douglas->new;
+my $obj = Test::Shared::Fixture::Wikibase::Datatype::Value::Item::Wikidata::Michal->new;
 
 # Print out.
 print scalar Wikibase::Datatype::Print::Value::Item::print($obj);
 
 # Output:
-# Q463035
\ No newline at end of file
+# Q18563993
\ No newline at end of file
