@@ -5,10 +5,11 @@ use warnings;
 
 use Error::Pure qw(err);
 use Mo qw(build default is);
-use Mo::utils qw(check_array_object check_number check_number_of_items);
+use Mo::utils qw(check_number check_number_of_items);
+use Mo::utils::Array qw(check_array_object);
 use Wikibase::Datatype::Value::Monolingual;
 
-our $VERSION = 0.37;
+our $VERSION = 0.38;
 
 has aliases => (
 	default => [],
@@ -64,17 +65,14 @@ sub BUILD {
 	my $self = shift;
 
 	# Check aliases.
-	check_array_object($self, 'aliases', 'Wikibase::Datatype::Value::Monolingual',
-		'Alias');
+	check_array_object($self, 'aliases', 'Wikibase::Datatype::Value::Monolingual');
 
 	# Check descriptions.
-	check_array_object($self, 'descriptions', 'Wikibase::Datatype::Value::Monolingual',
-		'Description');
+	check_array_object($self, 'descriptions', 'Wikibase::Datatype::Value::Monolingual');
 	check_number_of_items($self, 'descriptions', 'language', 'Description', 'language');
 
 	# Check labels.
-	check_array_object($self, 'labels', 'Wikibase::Datatype::Value::Monolingual',
-		'Label');
+	check_array_object($self, 'labels', 'Wikibase::Datatype::Value::Monolingual');
 	check_number_of_items($self, 'labels', 'language', 'Label', 'language');
 
 	# If length of value is greater than 250, strip.
@@ -99,13 +97,11 @@ sub BUILD {
 	check_number($self, 'page_id');
 
 	# Check sitelinks.
-	check_array_object($self, 'sitelinks', 'Wikibase::Datatype::Sitelink',
-		'Sitelink');
+	check_array_object($self, 'sitelinks', 'Wikibase::Datatype::Sitelink');
 	check_number_of_items($self, 'sitelinks', 'site', 'Sitelink', 'site');
 
 	# Check statements.
-	check_array_object($self, 'statements', 'Wikibase::Datatype::Statement',
-		'Statement');
+	check_array_object($self, 'statements', 'Wikibase::Datatype::Statement');
 
 	return;
 }
@@ -309,24 +305,46 @@ Returns string.
 =head1 ERRORS
 
  new():
-         From Mo::utils::check_array_object():
-                 Alias isn't 'Wikibase::Datatype::Value::Monolingual' object.
-                 Description isn't 'Wikibase::Datatype::Value::Monolingual' object.
-                 Label isn't 'Wikibase::Datatype::Value::Monolingual' object.
-                 Parameter 'aliases' must be a array.
-                 Parameter 'descriptions' must be a array.
-                 Parameter 'labels' must be a array.
-                 Parameter 'sitelinks' must be a array.
-                 Parameter 'statements' must be a array.
-                 Sitelink isn't 'Wikibase::Datatype::Sitelink' object.
-                 Statement isn't 'Wikibase::Datatype::Statement' object.
          From Mo::utils::check_page_id():
                  Parameter 'page_id' must a number.
+
          From Mo::utils::check_number_of_items():
                  Sitelink for site '%s' has multiple values.
                  Description for language '%s' has multiple values.
                  Label for language '%s' has multiple values.
 
+         From Mo::utils::Array::check_array_object():
+                 Parameter 'aliases' must be a array.
+                         Value: %s
+                         Reference: %s
+                 Parameter 'aliases' with array must contain 'Wikibase::Datatype::Value::Monolingual' objects.
+                         Value: %s
+                         Reference: %s
+                 Parameter 'descriptions' must be a array.
+                         Value: %s
+                         Reference: %s
+                 Parameter 'descriptions' with array must contain 'Wikibase::Datatype::Value::Monolingual' objects.
+                         Value: %s
+                         Reference: %s
+                 Parameter 'labels' must be a array.
+                         Value: %s
+                         Reference: %s
+                 Parameter 'labels' with array must contain 'Wikibase::Datatype::Value::Monolingual' objects.
+                         Value: %s
+                         Reference: %s
+                 Parameter 'sitelinks' must be a array.
+                         Value: %s
+                         Reference: %s
+                 Parameter 'sitelinks' with array must contain 'Wikibase::Datatype::Sitelink' objects.
+                         Value: %s
+                         Reference: %s
+                 Parameter 'statements' must be a array.
+                         Value: %s
+                         Reference: %s
+                 Parameter 'statements' with array must contain 'Wikibase::Datatype::Statement' objects.
+                         Value: %s
+                         Reference: %s
+
 =head1 EXAMPLE
 
 =for comment filename=create_and_print_item.pl
@@ -590,7 +608,8 @@ Returns string.
 
 L<Error::Pure>,
 L<Mo>,
-L<Mo:utils>.
+L<Mo:utils>,
+L<Mo:utils::Array>.
 
 =head1 SEE ALSO
 
@@ -620,6 +639,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.37
+0.38
 
 =cut
