@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use Error::Pure qw(err);
-use List::MoreUtils qw(none);
+use List::Util 1.33 qw(none);
 use Mo qw(build is);
 use Mo::utils qw(check_isa check_required);
 use Readonly;
@@ -16,7 +16,7 @@ Readonly::Array our @SNAK_TYPES => qw(
 	value
 );
 
-our $VERSION = 0.37;
+our $VERSION = 0.38;
 
 has datavalue => (
 	is => 'ro',
@@ -193,7 +193,7 @@ Returns string.
 =head1 DEPENDENCIES
 
 L<Error::Pure>,
-L<List::MoreUtils>,
+L<List::Util>,
 L<Mo>,
 L<Mo::utils>,
 L<Readonly>,
@@ -231,6 +231,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.37
+0.38
 
 =cut
